Aware

Trait Aware 

pub trait Aware {
    // Required method
    fn aware(self) -> Self;
}
Allows you to implement aware for egui entities so hframe can know about their existence when applying compositions.

Required Methods

fn aware(self) -> Self

Let hframe know about the existence of this entity.

You must call this in anything from the egui world that can overlap with HTML content (like normal egui windows).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<R> Aware for Option<InnerResponse<R>>

Source

fn aware(self) -> Self

Implementors